searchData={"content_type":"text/markdown","items":[{"doc":"To obtain prayer times for a specific location and date:\n\n  ```elixir\nprayer_times = PrayerTimes.compute(%{\n  method: :turkiye,\n  date: Date.utc_today(),\n  lat: 41.0082,\n  long: 28.9784,\n  timezone: 3\n})\n```\n\nThis will return a map with the prayer times as NaiveDateTime values, for example:\n\n```elixir\n%{\n  fajr: ~N[2023-11-22 06:21:00],\n  sunrise: ~N[2023-11-22 07:53:00],\n  dhuhr: ~N[2023-11-22 12:56:00],\n  asr: ~N[2023-11-22 15:25:00],\n  maghrib: ~N[2023-11-22 17:49:00],\n  isha: ~N[2023-11-22 19:13:00],\n  imsak: ~N[2023-11-22 06:13:00],\n  midnight: ~N[2023-11-22 00:50:00],\n  sunset: ~N[2023-11-22 17:40:00]\n}\n```\n\nParameters:\n```\n* method: The calculation method (e.g., `:mwl`, `:isna`, `:egypt`, `:makkah`, `:karachi`, `:tehran`, `:jafari`).\n* date: The date for which to calculate the prayer times (Date struct).\n* lat: Latitude of the location.\n* long: Longitude of the location.\n* timezone: UTC offset for the location's timezone.\n```","ref":"PrayerTimes.html","title":"PrayerTimes","type":"module"},{"doc":"","ref":"PrayerTimes.html#compute/1","title":"PrayerTimes.compute/1","type":"function"},{"doc":"Handles the internal calculations for determining Islamic prayer times.\n\nThis module is primarily used by `PrayerTimes` to calculate accurate prayer times based on various methods and parameters like latitude, longitude, timezone, and date.","ref":"PrayerTimes.Calculation.html","title":"PrayerTimes.Calculation","type":"module"},{"doc":"The calculation involves converting the given date to the Julian date, computing the sun's position, and then adjusting the times according to the selected method and high latitude rules.\n\nThis module is not typically used directly in user applications; instead, use `PrayerTimes.compute/1`.","ref":"PrayerTimes.Calculation.html#module-details","title":"Details - PrayerTimes.Calculation","type":"module"},{"doc":"- `:mwl`: Muslim World League\n- `:isna`: Islamic Society of North America\n- `:egypt`: Egyptian General Authority of Survey\n- `:makkah`: Umm al-Qura University, Makkah\n- `:karahci`: University of Islamic Sciences, Karachi\n- `:tehran`: Institute of Geophysics, University of Tehran\n- `:jafari`: Shia Ithna-Ashari","ref":"PrayerTimes.Calculation.html#module-supported-methods","title":"Supported Methods - PrayerTimes.Calculation","type":"module"},{"doc":"","ref":"PrayerTimes.Calculation.html#adjust_high_lats/2","title":"PrayerTimes.Calculation.adjust_high_lats/2","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#adjust_high_lats_time/6","title":"PrayerTimes.Calculation.adjust_high_lats_time/6","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#adjust_times/4","title":"PrayerTimes.Calculation.adjust_times/4","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#apply_offsets/2","title":"PrayerTimes.Calculation.apply_offsets/2","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#asr_factor/1","title":"PrayerTimes.Calculation.asr_factor/1","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#asr_time/4","title":"PrayerTimes.Calculation.asr_time/4","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#compute_prayer_times/4","title":"PrayerTimes.Calculation.compute_prayer_times/4","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#compute_times/5","title":"PrayerTimes.Calculation.compute_times/5","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#day_portion/1","title":"PrayerTimes.Calculation.day_portion/1","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#get_times/1","title":"PrayerTimes.Calculation.get_times/1","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#mid_day/2","title":"PrayerTimes.Calculation.mid_day/2","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#night_portion/3","title":"PrayerTimes.Calculation.night_portion/3","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#rise_set_angle/1","title":"PrayerTimes.Calculation.rise_set_angle/1","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#sun_angle_time/5","title":"PrayerTimes.Calculation.sun_angle_time/5","type":"function"},{"doc":"","ref":"PrayerTimes.Calculation.html#sun_position/1","title":"PrayerTimes.Calculation.sun_position/1","type":"function"},{"doc":"Handles the different calculation methods for determining Islamic prayer times.","ref":"PrayerTimes.Methods.html","title":"PrayerTimes.Methods","type":"module"},{"doc":"The following calculation methods are supported, each with its specific parameters for Fajr and Isha prayers:\n\n* `:mwl` - Muslim World League\n  - Fajr angle: 18, Isha angle: 17\n* `:isna` - Islamic Society of North America (ISNA)\n  - Fajr angle: 15, Isha angle: 15\n* `:egypt` - Egyptian General Authority of Survey\n  - Fajr angle: 19.5, Isha angle: 17.5\n* `:makkah` - Umm Al-Qura University, Makkah\n  - Fajr angle: 18.5, Isha time: 90 minutes after Maghrib\n* `:karachi` - University of Islamic Sciences, Karachi\n  - Fajr angle: 18, Isha angle: 18\n* `:tehran` - Institute of Geophysics, University of Tehran\n  - Fajr angle: 17.7, Isha angle: 14, Maghrib angle: 4.5, Midnight: Jafari\n* `:jafari` - Shia Ithna-Ashari, Leva Institute, Qum\n  - Fajr angle: 16, Isha angle: 14, Maghrib angle: 4, Midnight: Jafari\n* `:turkiye` - Presidency of Religious Affairs, Türkiye\n  - Fajr angle: 18, Isha angle: 17, Maghrib time: 9 minutes after sunset\n  - Time offsets: Fajr: -2, Sunrise: -7, Dhuhr: 6, Asr: 4, Isha: 2","ref":"PrayerTimes.Methods.html#module-supported-calculation-methods","title":"Supported Calculation Methods - PrayerTimes.Methods","type":"module"},{"doc":"Each method can be specified when calling the `PrayerTimes.compute/1` function to get the prayer times according to that method.","ref":"PrayerTimes.Methods.html#module-usage","title":"Usage - PrayerTimes.Methods","type":"module"},{"doc":"","ref":"PrayerTimes.Methods.html#get_offsets/1","title":"PrayerTimes.Methods.get_offsets/1","type":"function"},{"doc":"","ref":"PrayerTimes.Methods.html#get_params/1","title":"PrayerTimes.Methods.get_params/1","type":"function"},{"doc":"","ref":"PrayerTimes.Methods.html#get_settings/1","title":"PrayerTimes.Methods.get_settings/1","type":"function"},{"doc":"","ref":"PrayerTimes.Methods.html#offset/2","title":"PrayerTimes.Methods.offset/2","type":"function"},{"doc":"","ref":"PrayerTimes.Methods.html#param/2","title":"PrayerTimes.Methods.param/2","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html","title":"PrayerTimes.Utils","type":"module"},{"doc":"","ref":"PrayerTimes.Utils.html#arccos/1","title":"PrayerTimes.Utils.arccos/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#arccot/1","title":"PrayerTimes.Utils.arccot/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#arcsin/1","title":"PrayerTimes.Utils.arcsin/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#arctan2/2","title":"PrayerTimes.Utils.arctan2/2","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#arctan/1","title":"PrayerTimes.Utils.arctan/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#cos/1","title":"PrayerTimes.Utils.cos/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#degrees/1","title":"PrayerTimes.Utils.degrees/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#fixangle/1","title":"PrayerTimes.Utils.fixangle/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#fixhour/1","title":"PrayerTimes.Utils.fixhour/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#float_to_datetime/1","title":"PrayerTimes.Utils.float_to_datetime/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#radians/1","title":"PrayerTimes.Utils.radians/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#sin/1","title":"PrayerTimes.Utils.sin/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#tan/1","title":"PrayerTimes.Utils.tan/1","type":"function"},{"doc":"","ref":"PrayerTimes.Utils.html#time_diff/2","title":"PrayerTimes.Utils.time_diff/2","type":"function"},{"doc":"# PrayerTimes\n\nConfigurable calculation package for Muslim prayer times in Elixir.","ref":"readme.html","title":"PrayerTimes","type":"extras"},{"doc":"Add `prayer_times` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:prayer_times, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - PrayerTimes","type":"extras"},{"doc":"To obtain prayer times for a specific location and date:\n\n```elixir\nprayer_times = PrayerTimes.compute(%{\n  method: :turkiye,\n  date: Date.utc_today(),\n  lat: 41.0082,\n  long: 28.9784,\n  timezone: 3\n})\n```\n\nThis will return a map with the prayer times as NaiveDateTime values, for example:\n\n```elixir\n%{\n  fajr: ~N[2023-11-22 06:21:00],\n  sunrise: ~N[2023-11-22 07:53:00],\n  dhuhr: ~N[2023-11-22 12:56:00],\n  asr: ~N[2023-11-22 15:25:00],\n  maghrib: ~N[2023-11-22 17:49:00],\n  isha: ~N[2023-11-22 19:13:00],\n  imsak: ~N[2023-11-22 06:13:00],\n  midnight: ~N[2023-11-22 00:50:00],\n  sunset: ~N[2023-11-22 17:40:00]\n}\n```\n\n\n#","ref":"readme.html#usage","title":"Usage - PrayerTimes","type":"extras"},{"doc":"* method: The calculation method (e.g., `:mwl`, `:isna`, `:egypt`, `:makkah`, `:karachi`, `:tehran`, `:jafari`).\n* date: The date for which to calculate the prayer times (Date struct).\n* lat: Latitude of the location.\n* long: Longitude of the location.\n* timezone: UTC offset for the location's timezone.\n\n#","ref":"readme.html#parameters","title":"Parameters - PrayerTimes","type":"extras"},{"doc":"* `:mwl` - Muslim World League\n  * `:isna` - Islamic Society of North America (ISNA)\n  * `:egypt` - Egyptian General Authority of Survey\n  * `:makkah` - Umm Al-Qura University, Makkah\n  * `:karachi` - University of Islamic Sciences, Karachi\n  * `:tehran` - Institute of Geophysics, University of Tehran\n  * `:jafari` - Shia Ithna-Ashari, Leva Institute, Qum\n  * `:turkiye` - Presidency of Religious Affairs, Türkiye","ref":"readme.html#supported-calculation-methods","title":"Supported calculation methods: - PrayerTimes","type":"extras"}]}